@@ -20,24 +20,12 @@ class http_server:
         self.async_update_list = []
         self.update_elapse = 0.1
         self.running = True
-        self.routes = web.RouteTableDef()
-        self.route_get = self.routes.get
-        self.route_post = self.routes.post
-        self.route_head = self.routes.head
-        self.route_patch = self.routes.patch
-        self.route_put = self.routes.put
-        self.route_static = self.routes.static
-        self.route_view = self.routes.view
-        self.route = self.routes.route
-
-    def add_route(self, method, path, handler):
-        self.app.router.add_route(method, path, handler)
-
-    def add_routes(self, routes):
-        self.app.router.add_routes(routes)
+        self.router = self.app.router
+        self.add_route = self.app.router.add_route
+        self.add_routes = self.app.router.add_routes
+        self.add_static = self.app.router.add_static
 
     async def common_run(self):
-        self.add_routes(self.routes)
         runner = web.AppRunner(self.app)
         await runner.setup()
         site = web.TCPSite(runner, host=self.host, port=self.port)
@@ -66,7 +54,6 @@ class http_server:
         await site.stop()
 
     def run(self):
-        self.add_routes(self.routes)
         web.run_app(self.app, host=self.host, port=self.port)
 
     def add_update_func(self, f):
@@ -74,3 +61,10 @@ class http_server:
 
     def add_async_update_func(self, f):
         self.async_update_list.append(f)
+
+    def route(self, method, path):
+        def f(func):
+            self.add_route(method, path, func)
+            return func
+        return f
+        
